<?php if ( ! defined( 'ABSPATH' ) ) { exit; } 

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

class LTE_Team_Widget extends Widget_Base {

	public function __construct($data = [], $args = null) {

		parent::__construct($data, $args);

		wp_enqueue_script('swiper');
		wp_enqueue_script('lte-frontend');
	}

	public function get_script_depends() {
		return [ 'lte-frontend' ];
	}
	
	public function get_name() {
		return 'lte-team';
	}

	public function get_title() {
		return esc_html__( 'Team', 'lte-ext' );
	}

	public function get_icon() {
		return 'eicon-lock-user';
	}

	public function get_categories() {
		return [ 'lte-category' ];
	}

	protected function _register_controls() {

		$categories = get_categories( [ 'taxonomy' => 'team-category' ] );
		foreach ($categories as $item) {

			$cats[$item->term_id] = $item->name;
		}		

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Layout', 'lte-ext' ),
			]
		);

			$this->add_control(
				'important_note',
				[
					'type' => \Elementor\Controls_Manager::RAW_HTML,
					'raw' => esc_html__( "The content of team can be edited in Team menu of Dashboard.", 'lte-ext'),
				]
			);		

			$this->add_control(
				'layout',
				[
					'label' => esc_html__( 'Layout', 'lte-ext' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'static',
					'label_block' => true,
					'options' => [
						'swiper'	=>	esc_html__( 'Slider', 'lte-ext' ),
						'static'	=>	esc_html__( 'Static', 'lte-ext' ),
					],
				]
			);		

			$this->add_control(
				'cat',
				[
					'label' => esc_html__( 'Category', 'lte-ext' ),
					'type' => Controls_Manager::SELECT,
					'label_block' => true,
					'default' => '',
					'options' => $cats,
				]
			);	

			$this->add_control(
				'limit',
				[
					'label' => esc_html__( 'Limit', 'lte-ext' ),
					'type' => Controls_Manager::TEXT,
					'default' => '4',
				]
			);

			$this->add_control(
				'ids',
				[
					'label' => esc_html__( 'Filter IDs', 'lte-ext' ),
					'type' => Controls_Manager::TEXT,
					'label_block' => true,
					'description' => esc_html__("Enter IDs to show, separated by comma", 'lte-ext'),
					'default' => '',
				]
			);

			$this->add_control(
				'orderby',
				[
					'label' => esc_html__( 'Order By', 'lte-ext' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'date',
					'options' => [
						'date'			=>	esc_html__( 'Date', 'lte-ext' ),
						'ID'			=>	esc_html__( 'ID', 'lte-ext' ),
						'menu_order'	=>	esc_html__( 'Menu Order', 'lte-ext' ),
						'title'			=>	esc_html__( 'Title', 'lte-ext' ),
						'rand'			=>	esc_html__( 'Random', 'lte-ext' ),

					],
				]
			);

			$this->add_control(
				'orderway',
				[
					'label' => esc_html__( 'Sort Order', 'lte-ext' ),
					'type' 	=> Controls_Manager::SELECT,
					'default' => 'DESC',
					'options' => [
						'DESC' => esc_html__( 'Descending', 'lte-ext' ),
						'ASC' => esc_html__( 'Ascending', 'lte-ext' )
					],
				]
			);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_cols',
			[
				'label' => esc_html__( 'Responsive Columns', 'lte-ext' ),
			]
		);

			$this->add_control(
				'important_columns',
				[
					'type' => \Elementor\Controls_Manager::RAW_HTML,
					'raw' => esc_html__( "Please consider some column settings could not work correctly with shortcode.", 'lte-ext'),
				]
			);			

			foreach ( lte_elementor_responsive_options([ 1 => 1, 2, 3, 4, 5, 6, 12 ]) as $key => $val ) {

				$val['type'] = Controls_Manager::SELECT;
				$this->add_control( $key, $val );
			}

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		lte_sc_output('team', $settings);
	}
}




